Renaming onlab-thirdparty to atomix

Change-Id: I258b80c9bd6481664585812bca738651fd348363
diff --git a/core/store/primitives/pom.xml b/core/store/primitives/pom.xml
index 86fa6a3..a011e7d 100644
--- a/core/store/primitives/pom.xml
+++ b/core/store/primitives/pom.xml
@@ -63,15 +63,16 @@
             <scope>test</scope>
         </dependency>
 
-        <!-- for shaded atomix/copycat -->
-        <dependency>
-            <groupId>org.onosproject</groupId>
-            <artifactId>onlab-thirdparty</artifactId>
-        </dependency>
         <dependency>
             <groupId>commons-io</groupId>
             <artifactId>commons-io</artifactId>
             <version>${commons.io.version}</version>
         </dependency>
+
+        <dependency>
+            <groupId>org.onosproject</groupId>
+            <artifactId>atomix</artifactId>
+            <version>1.0.onos-SNAPSHOT</version>
+        </dependency>
     </dependencies>
 </project>
diff --git a/docs/external-excludes b/docs/external-excludes
index dade4d4..c9bd2b0 100644
--- a/docs/external-excludes
+++ b/docs/external-excludes
@@ -6,7 +6,7 @@
 org.onlab.stc*
 org.onlab.catalyst*
 
-org.onlab.thirdparty
+org.onlab.atomix
 org.onosproject.provider*
 org.onosproject.rest
 org.onosproject.cli*
diff --git a/docs/internal-excludes b/docs/internal-excludes
index 81e6329..7ac0a66 100644
--- a/docs/internal-excludes
+++ b/docs/internal-excludes
@@ -1,7 +1,7 @@
 org.onlab.jdvue*
 org.onlab.stc*
 org.onlab.catalyst*
-org.onlab.thirdparty
+org.onlab.atomix
 org.onosproject.oecfg
 org.onosproject.maven
 org.onosproject.grpc*
diff --git a/features/features.xml b/features/features.xml
index 26d0945..bc8cb17 100644
--- a/features/features.xml
+++ b/features/features.xml
@@ -56,7 +56,7 @@
         <bundle>mvn:com.typesafe/config/1.2.1</bundle>
         <bundle>wrap:mvn:com.googlecode.concurrent-trees/concurrent-trees/2.4.0$Bundle-SymbolicName=concurrent-trees&amp;Bundle-Version=2.4.0</bundle>
         <bundle>mvn:commons-io/commons-io/2.4</bundle>
-        <bundle>mvn:org.onosproject/onlab-thirdparty/@ONOS-VERSION</bundle>
+        <bundle>mvn:org.onosproject/atomix/1.0.onos-SNAPSHOT</bundle>
 
         <bundle>mvn:org.glassfish.jersey.core/jersey-client/2.22.2</bundle>
 
diff --git a/pom.xml b/pom.xml
index 83330f4..5eccdbc 100644
--- a/pom.xml
+++ b/pom.xml
@@ -77,10 +77,6 @@
         <project.build.sourceEncoding>UTF-8</project.build.sourceEncoding>
         <onos-build-conf.version>1.3-SNAPSHOT</onos-build-conf.version>
         <netty4.version>4.0.33.Final</netty4.version>
-        <!-- TODO: replace with final release version when it is out -->
-        <catalyst.version>1.0.6</catalyst.version>
-        <atomix.version>1.0.0-rc3</atomix.version>
-        <copycat.version>1.0.0-rc6</copycat.version>
         <openflowj.version>0.9.3.onos-SNAPSHOT</openflowj.version>
         <onos-maven-plugin.version>1.9</onos-maven-plugin.version>
         <osgi.version>4.3.1</osgi.version>
diff --git a/utils/thirdparty/pom.xml b/utils/atomix/pom.xml
similarity index 71%
rename from utils/thirdparty/pom.xml
rename to utils/atomix/pom.xml
index 8381be7..500b29d 100644
--- a/utils/thirdparty/pom.xml
+++ b/utils/atomix/pom.xml
@@ -21,15 +21,39 @@
 
   <parent>
     <groupId>org.onosproject</groupId>
-    <artifactId>onlab-utils</artifactId>
-    <version>1.6.0-SNAPSHOT</version>
-    <relativePath>../pom.xml</relativePath>
+    <artifactId>onos-base</artifactId>
+    <version>1</version>
+    <relativePath/>
   </parent>
 
-  <artifactId>onlab-thirdparty</artifactId>
+  <groupId>org.onosproject</groupId>
+  <artifactId>atomix</artifactId>
   <packaging>bundle</packaging>
+  <version>1.0.onos-SNAPSHOT</version>
 
-  <description>ONLab third-party dependencies</description>
+  <description>Atomix shaded OSGi JAR</description>
+  <url>http://onosproject.org/</url>
+
+  <scm>
+    <connection>scm:git:https://gerrit.onosproject.org/onos</connection>
+    <developerConnection>scm:git:https://gerrit.onosproject.org/onos
+    </developerConnection>
+    <url>http://gerrit.onosproject.org/</url>
+  </scm>
+
+  <licenses>
+    <license>
+      <name>Apache License, Version 2.0</name>
+      <url>http://www.apache.org/licenses/LICENSE-2.0.txt</url>
+    </license>
+  </licenses>
+
+  <properties>
+    <!-- TODO: replace with final release version when it is out -->
+    <catalyst.version>1.0.6</catalyst.version>
+    <atomix.version>1.0.0-rc3</atomix.version>
+    <copycat.version>1.0.0-rc6</copycat.version>
+  </properties>
 
   <dependencies>
     <dependency>
@@ -68,10 +92,22 @@
     <plugins>
       <plugin>
         <groupId>org.apache.maven.plugins</groupId>
+        <artifactId>maven-compiler-plugin</artifactId>
+        <!-- TODO: update once following issue is fixed. -->
+        <!-- https://jira.codehaus.org/browse/MCOMPILER-205 -->
+        <version>2.5.1</version>
+        <configuration>
+          <source>1.8</source>
+          <target>1.8</target>
+        </configuration>
+      </plugin>
+
+      <plugin>
+        <groupId>org.apache.maven.plugins</groupId>
         <artifactId>maven-shade-plugin</artifactId>
+        <version>2.4.2</version>
         <configuration>
           <createSourcesJar>true</createSourcesJar>
-
           <artifactSet>
             <excludes>
               <!-- exclude OSGi-ready transitive dependencies -->
@@ -83,7 +119,6 @@
               <exclude>commons-io:commons-io</exclude>
             </excludes>
           </artifactSet>
-
           <filters>
             <filter>
               <artifact>io.atomix:atomix-all</artifact>
@@ -91,7 +126,6 @@
                   <include>**</include>
                 </includes>
             </filter>
-
           </filters>
         </configuration>
         <executions>
@@ -106,6 +140,8 @@
       <plugin>
         <groupId>org.apache.felix</groupId>
         <artifactId>maven-bundle-plugin</artifactId>
+        <version>3.0.1</version>
+        <extensions>true</extensions>
         <configuration>
           <instructions>
             <Export-Package>
diff --git a/utils/pom.xml b/utils/pom.xml
index f1a9d97..e4ac3da 100644
--- a/utils/pom.xml
+++ b/utils/pom.xml
@@ -32,12 +32,12 @@
     <description>Domain agnostic ON.Lab utilities</description>
 
     <modules>
+        <module>atomix</module>
         <module>junit</module>
         <module>misc</module>
         <module>yangutils</module>
         <module>osgi</module>
         <module>rest</module>
-        <module>thirdparty</module>
         <module>stc</module>
         <module>jdvue</module>
         <module>osgiwrap</module>
diff --git a/utils/thirdparty/src/main/java/org/onlab/thirdparty/OnlabThirdparty.java b/utils/atomix/src/main/java/org/onlab/atomix/AtomixShaded.java
similarity index 82%
rename from utils/thirdparty/src/main/java/org/onlab/thirdparty/OnlabThirdparty.java
rename to utils/atomix/src/main/java/org/onlab/atomix/AtomixShaded.java
index 217ee02..7408e33 100644
--- a/utils/thirdparty/src/main/java/org/onlab/thirdparty/OnlabThirdparty.java
+++ b/utils/atomix/src/main/java/org/onlab/atomix/AtomixShaded.java
@@ -13,14 +13,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.thirdparty;
-
+package org.onlab.atomix;
 
 /**
  * Empty class required to get the onlab-thirdparty module to build properly.
  *
  * NOTE Required for shade plugin to operate.
  */
-public class OnlabThirdparty {
+public class AtomixShaded {
 
 }
@@ -13,14 +13,13 @@
 
 /**
- * Empty class required to get the onlab-thirdparty module to build properly.
+ * Empty class required to get the atomix module to build properly.
  *
  * NOTE Required for shade plugin to operate.